
#ifndef __DUMP_H__
#define __DUMP_H__

#include "defs.h"

void            dump_hex();
void            dump_text();
void            dump_update();

enum
{
    DUMP_HEX,
    DUMP_TEXT,
    DUMP_N
};

struct _dump
{
    gulong      handler[DUMP_N];
    GtkWidget   *dlg[DUMP_N], *view[DUMP_N], *page[DUMP_N], *offset;
    GtkTextBuffer *buf[DUMP_N];
} dump;

#endif /* __DUMP_H__ */
